@@ -419,7 +419,7 @@ shinyServer(
         invi=c("ind","quali")
       }
       if(!(is.null(habi))){
-      plot.MFA(values()$res.MFA,choix="ind",axes=c(as.numeric(input$nb1),as.numeric(input$nb2)),partial=part,lab.ind=input$meanind, lab.par=lapbar,lab.var=input$qualind, habillage=habi,invisible=invi)
+      plot.MFA(values()$res.MFA,choix="ind",axes=c(as.numeric(input$nb1),as.numeric(input$nb2)),title=input$title2,partial=part,lab.ind=input$meanind, lab.par=lapbar,lab.var=input$qualind, habillage=habi,invisible=invi)
       }
     }
     
@@ -442,10 +442,15 @@ shinyServer(
         selec=paste("contrib ",input$slider2)
       }
       if(input$selection=="cos2"){
-        selec=paste("cos2 ",input$slider3)
+        if(input$slider3!=1){
+          selec=paste("cos2 ",input$slider3)
+        }
+        else{
+          selec="cos2 0.999"
+        }
       }
       invi="none"
-      plot.MFA(values()$res.MFA,choix="var",axes=c(as.numeric(input$nb1),as.numeric(input$nb2)),habillage=habi,select=selec,invisible=invi)
+      plot.MFA(values()$res.MFA,choix="var",axes=c(as.numeric(input$nb1),as.numeric(input$nb2)),title=input$title3,habillage=habi,select=selec,invisible=invi)
     })
     
     output$map22=renderUI({
@@ -475,7 +480,7 @@ shinyServer(
       validate(
         need(input$nb1 != input$nb2, "Please select two different dimensions")
       )
-      plot.MFA(values()$res.MFA,choix="group",axes=c(as.numeric(input$nb1),as.numeric(input$nb2)))
+      plot.MFA(values()$res.MFA,choix="group",title=input$title1,axes=c(as.numeric(input$nb1),as.numeric(input$nb2)))
     }
     
     output$map5 <- renderPlot({
@@ -496,7 +501,7 @@ shinyServer(
       else{
         habi="none"
       }
-      plot.MFA(values()$res.MFA,choix="axes",axes=c(as.numeric(input$nb1),as.numeric(input$nb2)),habillage=habi)
+      plot.MFA(values()$res.MFA,choix="axes",axes=c(as.numeric(input$nb1),as.numeric(input$nb2)),title=input$title4,habillage=habi)
     }
     
     output$map4 <- renderPlot({
@@ -510,7 +515,7 @@ shinyServer(
       if(input$affichcol==FALSE){
         col=FALSE
       }
-      plot.MFA(values()$res.MFA,choix="freq",axes=c(as.numeric(input$nb1),as.numeric(input$nb2)),lab.col=col)
+      plot.MFA(values()$res.MFA,choix="freq",axes=c(as.numeric(input$nb1),as.numeric(input$nb2)),title=input$title5,lab.col=col)
     })
     
     output$map66=renderUI({
@@ -628,7 +633,7 @@ shinyServer(
       if (input$qualind1==FALSE && input$meanind1==FALSE){
         invi=c("ind","quali")
       }
-      Call1=as.name(paste("plot.MFA(res,choix='ind',axes=c(",input$nb1,",",input$nb2,"),partial=",part,",lab.ind=",input$meanind,",lab.par=",lapbar,",lab.var=",input$qualind, ",habillage='",habi,"',invisible='",invi,"')",sep=""))
+      Call1=as.name(paste("plot.MFA(res,choix='ind',axes=c(",input$nb1,",",input$nb2,"),partial=",part,",title='",input$title2,"',lab.ind=",input$meanind,",lab.par=",lapbar,",lab.var=",input$qualind, ",habillage='",habi,"',invisible='",invi,"')",sep=""))
       return(Call1)
     }
     
@@ -646,15 +651,20 @@ shinyServer(
         selec=paste("contrib ",input$slider2)
       }
       if(input$selection=="cos2"){
-        selec=paste("cos2 ",input$slider3)
+        if(input$slider3!=1){
+          selec=paste("cos2 ",input$slider3)
+        }
+        else{
+          selec="cos2 0.999"
+        }
       }
       invi="none"
-      Call2=paste("plot.MFA(res,choix='var',axes=c(",input$nb1,",",input$nb2,"),habillage='",habi,"',select=",selec,",invisible='",invi,"')",sep="")
+      Call2=paste("plot.MFA(res,choix='var',axes=c(",input$nb1,",",input$nb2,"),habillage='",habi,"',title='",input$title3,"',select=",selec,",invisible='",invi,"')",sep="")
       return(Call2)
     }
     
     codeGraph3<-function(){
-      Call3=paste("plot.MFA(res,choix='group',axes=c(",input$nb1,",",input$nb2,"))",sep="")
+      Call3=paste("plot.MFA(res,choix='group',title='",input$title1,"',axes=c(",input$nb1,",",input$nb2,"))",sep="")
       return(Call3)
     }
     
@@ -665,7 +675,7 @@ shinyServer(
       else{
         habi="none"
       }
-      Call4=paste("plot.MFA(res,choix='axes',axes=c(",input$nb1,",",input$nb2,"),habillage='",habi,"')",sep="")
+      Call4=paste("plot.MFA(res,choix='axes',title='",input$title4,"',axes=c(",input$nb1,",",input$nb2,"),habillage='",habi,"')",sep="")
       return(Call4)
     }
     
@@ -676,7 +686,7 @@ shinyServer(
       if(input$affichcol==FALSE){
         col=FALSE
       }
-      Call5=paste("plot.MFA(res,choix='freq',axes=c(",input$nb1,",",input$nb2,"),lab.col=",col,")",sep="")
+      Call5=paste("plot.MFA(res,choix='freq',title='",input$title5,"',axes=c(",input$nb1,",",input$nb2,"),lab.col=",col,")",sep="")
       return(Call5)
     }
     
@@ -726,6 +736,11 @@ shinyServer(
       res$code3=codeGraph3()
       res$code4=codeGraph4()
       res$code5=codeGraph5()
+      res$title1=input$title1
+      res$title2=input$title2
+      res$title3=input$title3
+      res$title4=input$title4
+      res$title5=input$title5
       class(res)="MFAshiny"
       return(res)
     }
@@ -737,7 +752,7 @@ shinyServer(
       )
       maxlength=dim(values()$res.MFA$quanti.var$coord)[1]
       if(input$selection=="contrib"){
-        return(sliderInput("slider2","Number of the most contributive variables",min=0, max=maxlength, value=maxlength, step=1))
+        return(sliderInput("slider2","Number of the most contributive variables",min=1, max=maxlength, value=maxlength, step=1))
       }
       if(input$selection=="cos2"){
         return(sliderInput("slider3","Number of variables with highest cos2",min=0, max=maxlength, value=maxlength, step=1))
