@@ -14,6 +14,8 @@ if(inherits(x, "data.frame")){
   selection4=NULL
   size=1
   size2=1
+  titre1="Individuals factor map (PCA)"
+  titre2="Variables factor map (PCA)"
 }
 
 if(inherits(x, "PCAshiny")){
@@ -31,6 +33,8 @@ if(inherits(x, "PCAshiny")){
   selection4=x$k
   size=x$l
   size2=x$m
+  titre1=x$title1
+  titre2=x$title2
 }
 if(inherits(x, "PCA")){
   nomData=as.character(x$call$call[2])
@@ -49,6 +53,8 @@ if(inherits(x, "PCA")){
   selection4=NULL
   size=1
   size2=1
+  titre1="Individuals factor map (PCA)"
+  titre2="Variables factor map (PCA)"
 }  
 
 quanti=names(which(sapply(newdata,is.numeric)))
